# -*- coding: utf-8 -*-
from django.conf import settings


DEFAULT_THEMES = {
    'arta': 'Arta',
    'ascetic': 'Ascetic',
    'atelier-dune.dark': 'Atelier Dune - Dark',
    'atelier-dune.light': 'Atelier Dune - Light',
    'atelier-forest.dark': 'Atelier forest - Dark',
    'atelier-forest.light': 'Atelier forest - Light',
    'atelier-heath.dark': 'Atelier heath - Dark',
    'atelier-heath.light': 'Atelier heath - Light',
    'atelier-lakeside.dark': 'Atelier lakeside - Dark',
    'atelier-lakeside.light': 'Atelier lakeside - Light',
    'atelier-seaside.dark': 'Atelier seaside - Dark',
    'atelier-seaside.light': 'Atelier seaside - Light',
    'brown_paper': 'Brown Paper',
    'dark': 'Dark',
    'default': 'Default',
    'docco': 'Docco',
    'far': 'Far',
    'foundation': 'Foundation',
    'github': 'Github',
    'googlecode': 'GoogleCode',
    'idea': 'IDEA',
    'ir_black': 'Ir black',
    'magula': 'Magula',
    'mono-blue': 'Mono Blue',
    'monokai': 'Monokai',
    'monokai_sublime': 'Monokai sublime',
    'obsidian': 'Obsidian',
    'paraiso.dark': 'Paraiso - Dark',
    'paraiso.light': 'éaraiso - Light',
    'pojoaque': 'Pojoaque',
    'railscasts': 'RailsCasts',
    'rainbow': 'Rainbow',
    'school_book': 'School Book',
    'solarized_dark': 'Solarized - Dark',
    'solarized_light': 'Solarized - Light',
    'sunburst': 'Sunburst',
    'tomorrow': 'Tomorrow',
    'tomorrow-night-blue': 'Tomorrow night - Blug',
    'tomorrow-night-bright': 'Tomorrow night - Bright',
    'tomorrow-night': 'Tomorrow night',
    'tomorrow-night-eighties': 'Tomorrow night - Eighties',
    'vs': 'VS',
    'xcode': 'XCode',
    'zenburn': 'Zenburn',
}

HIGHLIGHT_THEME = getattr(settings, 'HIGHLIGHT_THEME', DEFAULT_THEMES)