{% load static sekizai_tags %}
{% addtoblock "css" %}
<link rel="stylesheet" href="{% static theme %}">
{% endaddtoblock %}

{% addtoblock "js" %}
	<script src="{% static highlight %}"></script>
	<script>
		$(document).ready(function() {
			$('pre#highlight-{{ instance.pk }} code').each(function(i, e) {hljs.highlightBlock(e)});
		});
	</script>
{% endaddtoblock %}
<pre id="highlight-{{ instance.pk }}" class="highlight-js">
	{% if instance.filename %}<strong>{{ instance.filename }}</strong>{% endif %}
	<code>{{ instance.body|safe }}</code>
</pre>